@@ -292,13 +292,13 @@ class VSOClient(BaseClient):
                 if name.count('"') >= 2:
                     name = name.split('"')[1]
 
-        if name is None:
+        # This is a hack to to prevent IRIS data from being labelled as XML files
+        if name is None and "VOEvent_IRIS" not in queryresponserow['fileid']:
             # Advice from the VSO is to fallback to providerid + fileid for a filename
             # As it's possible multiple providers give the same fileid.
             # However, I haven't implemented this yet as it would be a breaking
             # change to the filenames we expect.
             fileid = queryresponserow['fileid']
-
             # Some providers make fileid a path
             # Some also don't specify a file extension, but not a lot we can do
             # about that.
@@ -314,7 +314,6 @@ class VSOClient(BaseClient):
         # If absolutely everything else fails make a filename based on download time
         if not name:
             name = f"vso_file_{datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')}"
-
         fname = pattern.format(file=name,
                                **queryresponserow.response_block_map)
 
